# Log Helper

Es un paquete que tiene como propósito facilitar la gestión de logs en
una clase que herede o extienda del mismo. El paquete brinda la posibilidad
de almacenar en una variable los logs y ponerlos a disposición de la clase
que lo hereda para que registre los pasos en estos y así la clase que 
la llama pueda registrar en su log los pasos que se siguieron en la clase
en cuestión.

## Instalación
`pip install log-helper-bit3`


## Creadores

El paquete fue desarrollado por el equipo de desarrollo de la compañía
BITCUBICO Technology para su uso interno, el desarrollador de esta 
iniciativa es Mauricio Montoya Medrano